Installation
============

**xwmt** Python package for water mass transformation analysis that leverages xarray functionality

Install from conda-forge:

.. code-block:: bash

   conda install -c conda-forge xwmb

Install from PyPI:

.. code-block:: bash

   pip install xwmb


Install from GitHub:

.. code-block:: bash

   pip install git+https://github.com/hdrake/xwmb.git